@@ -24,6 +24,14 @@ class TalosClientConfig:
     _isAutoLocation = bool
     _scheduleInfoMaxRetry = int
     _updateScheduleInfoInterval = int
+    _falconUrl = str
+    _reportMetricIntervalMillis = int
+    _clientMonitorSwitch = bool
+    _consumerMetricFalconEndpoint = str
+    _producerMetricFalconEndpoint = str
+    _metricFalconStep = int
+    _alertType = str
+    _clusterName = str
 
     # producer configs
     _service_endpoint = str
@@ -51,6 +59,7 @@ class TalosClientConfig:
     _fetchMessageInterval = int
     _checkLastCommitOffset = bool
     _waitPartitionWorkingTime = int
+    _waitPartitionReduceTime = int
     _resetLatestOffsetWhenOutOfRange = bool
     _checkpointAutoCommit = bool
     _resetOffsetWhenStart = bool
@@ -78,6 +87,10 @@ class TalosClientConfig:
             TalosClientConfigKeys.GALAXY_TALOS_DEFAULT_SERVICE_ENDPOINT)
         if not self._serviceEndpint:
             raise RuntimeError("The property of 'galaxy.talos.service.endpoint' must be set")
+        self._clusterName = self.get_service_endpoint().replace("http://", "") \
+            .replace("https://", "") \
+            .replace(".api.xiaomi.net", "") \
+            .replace(".api.xiaomi.com", "")
         self._secureServiceEndpint = pro.get(
             TalosClientConfigKeys.GALAXY_TALOS_SECURE_SERVICE_ENDPOINT,
             TalosClientConfigKeys.GALAXY_TALOS_DEFAULT_SECURE_SERVICE_ENDPOINT)
@@ -102,6 +115,27 @@ class TalosClientConfig:
         self._fetchMessageInterval = pro.get(
             TalosClientConfigKeys.GALAXY_TALOS_CONSUMER_FETCH_INTERVAL,
             TalosClientConfigKeys.GALAXY_TALOS_CONSUMER_FETCH_INTERVAL_DEFAULT)
+        self._falconUrl = pro.get(
+            TalosClientConfigKeys.GALAXY_TALOS_METRIC_FALCON_URL,
+            TalosClientConfigKeys.GALAXY_TALOS_METRIC_FALCON_URL_DEFAULT)
+        self._reportMetricIntervalMillis = pro.get(
+            TalosClientConfigKeys.GALAXY_TALOS_REPORT_METRIC_INTERVAL_MILLIS,
+            TalosClientConfigKeys.GALAXY_TALOS_REPORT_METRIC_INTERVAL_MILLIS_DEFAULT)
+        self._clientMonitorSwitch = pro.get(
+            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_FALCON_MONITOR_SWITCH,
+            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_FALCON_MONITOR_SWITCH_DEFAULT)
+        self._consumerMetricFalconEndpoint = pro.get(
+            TalosClientConfigKeys.GALAXY_TALOS_CONSUMER_METRIC_FALCON_ENDPOINT,
+            TalosClientConfigKeys.GALAXY_TALOS_CONSUMER_METRIC_FALCON_ENDPOINT_DEFAULT)
+        self._producerMetricFalconEndpoint = pro.get(
+            TalosClientConfigKeys.GALAXY_TALOS_PRODUCER_METRIC_FALCON_ENDPOINT,
+            TalosClientConfigKeys.GALAXY_TALOS_PRODUCER_METRIC_FALCON_ENDPOINT_DEFAULT)
+        self._metricFalconStep = pro.get(
+            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_FALCON_STEP,
+            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_FALCON_STEP_DEFAULT)
+        self._alertType = pro.get(
+            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_ALERT_TYPE,
+            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_ALERT_TYPE_DEFAULT)
 
         self._maxBufferedMsgNumber = pro.get(
             TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_MAX_BUFFERED_MESSAGE_NUMBER,
@@ -166,6 +200,9 @@ class TalosClientConfig:
         self._waitPartitionWorkingTime = pro.get(
             TalosConsumerConfigKeys.GALAXY_TALOS_CONSUMER_WAIT_PARTITION_WORKING_TIME,
             TalosConsumerConfigKeys.GALAXY_TALOS_CONSUMER_WAIT_PARTITION_WORKING_TIME_DEFAULT)
+        self._waitPartitionReduceTime = pro.get(
+            TalosConsumerConfigKeys.GALAXY_TALOS_CONSUMER_WAIT_PARTITION_REDUCE_TIME,
+            TalosConsumerConfigKeys.GALAXY_TALOS_CONSUMER_WAIT_PARTITION_REDUCE_TIME_DEFAULT)
         self._resetLatestOffsetWhenOutOfRange = pro.get(
             TalosConsumerConfigKeys.GALAXY_TALOS_CONSUMER_OUT_OF_RANGE_RESET_LATEST_OFFSET,
             TalosConsumerConfigKeys.GALAXY_TALOS_CONSUMER_OUT_OF_RANGE_RESET_LATEST_OFFSET_DEFAULT)
@@ -290,6 +327,9 @@ class TalosClientConfig:
     def get_wait_partition_working_time(self):
         return self._waitPartitionWorkingTime
 
+    def get_wait_partition_reduce_time(self):
+        return self._waitPartitionReduceTime
+
     def get_update_partition_msg_number(self):
         return self._updatePartitionMsgNum
 
@@ -332,6 +372,30 @@ class TalosClientConfig:
     def get_client_ip(self):
         return self._clientIp
 
+    def get_falcon_url(self):
+        return self._falconUrl
+
+    def is_open_client_monitor(self):
+        return self._clientMonitorSwitch
+
+    def get_report_metric_interval_millis(self):
+        return self._reportMetricIntervalMillis
+
+    def get_consumer_metric_falcon_endpoint(self):
+        return self._consumerMetricFalconEndpoint
+
+    def get_producer_metric_falcon_endpoint(self):
+        return self._producerMetricFalconEndpoint
+
+    def get_metric_falcon_step(self):
+        return self._metricFalconStep
+
+    def get_alert_type(self):
+        return self._alertType
+
+    def get_cluster_name(self):
+        return self._clusterName
+
 
 
 
