@@ -63,7 +63,7 @@ class TalosConsumerDemo():
     accessSecret = "$yourSecretKey"
     topicName = "$yourTopicName"
     consumerGroup = "$yourConsumerGroupName"
-    clientPrefix = "#department-prefix"
+    clientPrefix = "$department-prefix"
 
     pro = dict()
     pro["galaxy.talos.service.endpoint"] = "$yourEndpoint"
