@@ -88,7 +88,7 @@ class PartitionMessageQueue:
             self.logger.debug("Ready to put message batch: " + str(len(returnList)) +
                               " queue size: " + str(len(self.userMessageList))
                               + " and curBytes: " + str(self.curMessageBytes) +
-                              " for partition: " + str(len(self.partitionId)))
+                              " for partition: " + str(self.partitionId))
         return returnList
 
     @synchronized
