@@ -18,9 +18,11 @@ from talos.admin.TalosAdmin import TalosAdmin
 from talos.utils import Utils
 from talos.utils.Utils import synchronized
 from talos.producer.PartitionSender import PartitionSender
+from talos.utils.FalconWriter import FalconWriter
 from threading import Timer
 import threading
 import random
+import traceback
 import logging
 
 
@@ -43,6 +45,9 @@ class TalosProducer(object):
     partitionCheckExecutor = threading.Timer
     partitionSenderMap = dict()
 
+    falconWriter = FalconWriter
+    producerMonitorThread = threading.Timer
+
     lock = threading.Lock()
 
     def __init__(self, producerConfig=None, credential=None, topicName=None, talosAdmin=None,
@@ -78,12 +83,15 @@ class TalosProducer(object):
                                                   self.maxBufferedMsgBytes)
         self.clientId = Utils.generate_client_id(producerConfig.get_client_ip(), "producer")
         self.synchronizedLock = threading.Lock()
+        self.falconWriter = FalconWriter(
+            falconUrl=self.talosProducerConfig.get_falcon_url())
 
         # getTopicTalosResourceName(producerConfig, credential);
         self.check_and_get_topic_info(self.topicTalosResourceName.topicTalosResourceName)
 
         self.init_partition_sender()
         self.init_check_partition_task()
+        self.init_producer_monitor_task()
 
         self.logger.info("Init a producer for topic: " +
                          self.topicTalosResourceName.topicTalosResourceName +
@@ -119,12 +127,23 @@ class TalosProducer(object):
             # update partitionNumber
             self.set_partition_number(topicPartitionNum)
 
-        self.partitionCheckExecutor = threading.Timer(interval=self.talosProducerConfig.
-                                                      get_producer_check_partition_interval(),
+        self.partitionCheckExecutor = threading.Timer(interval=self.talosProducerConfig
+                                                      .get_producer_check_partition_interval(),
                                                       function=self.check_partition_task)
-        self.partitionCheckExecutor.setName("partitionCheckTask-" + self.topicName)
+        self.partitionCheckExecutor.setName("talos-producer-partitionCheck-" + self.topicName)
         self.partitionCheckExecutor.start()
 
+    def producer_monitor_task(self):
+        try:
+            self.push_metric_data()
+        except Exception as throwable:
+            self.logger.error("push metric data to falcon failed." + str(traceback.format_exc()))
+        self.producerMonitorThread = threading.Timer(interval=self.talosProducerConfig
+                                                     .get_report_metric_interval_millis() / 1000,
+                                                     function=self.producer_monitor_task)
+        self.producerMonitorThread.setName("talos-producer-monitor-" + self.topicName)
+        self.producerMonitorThread.start()
+
     @synchronized
     def add_user_message(self, msgList=None, partitionId=None):
         if not self.is_active():
@@ -249,6 +268,7 @@ class TalosProducer(object):
         for key, value in self.partitionSenderMap.items():
             value.shutdown()
         self.partitionCheckExecutor.cancel()
+        self.producerMonitorThread.cancel()
 
     def adjust_partition_sender(self, newPartitionNum=None):
         if self.partitionNumber < newPartitionNum:
@@ -311,13 +331,27 @@ class TalosProducer(object):
         self.partitionCheckExecutor = Timer(interval=self.talosProducerConfig.
                                             get_producer_check_partition_interval(),
                                             function=self.check_partition_task)
-        self.partitionCheckExecutor.setName("partitionCheckTask-" + self.topicName)
+        self.partitionCheckExecutor.setName("talos-producer-partitionCheckTask-" + self.topicName)
         self.partitionCheckExecutor.start()
 
+    def init_producer_monitor_task(self):
+        if self.talosProducerConfig.is_open_client_monitor():
+            # push metric data to falcon every minutes
+            self.producerMonitorThread = Timer(interval=self.talosProducerConfig.
+                                               get_report_metric_interval_millis() / 1000,
+                                               function=self.producer_monitor_task)
+            self.producerMonitorThread.setName("talos-producer-monitor-" + self.topicName)
+            self.producerMonitorThread.start()
+
     def increase_buffered_count(self, incrementNumber=None, incrementBytes=None):
         self.bufferedCount.increase(incrementNumber, incrementBytes)
 
     def decrease_buffered_count(self, decrementNumber=None, decrementBytes=None):
         self.bufferedCount.decrease(decrementNumber, decrementBytes)
 
+    def push_metric_data(self):
+        jsonArray = []
+        for key, value in self.partitionSenderMap.items():
+            jsonArray += value.get_falcon_data()
+        self.falconWriter.push_falcon_data(jsonArray)
 
